package com.ecyrd.jspwiki.plugin;

// this package is only made for compatibility with JSPWiki

import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.Set;
import java.util.TreeMap;
import java.util.TreeSet;

import org.jboss.wiki.WikiInsidePlugin;
import org.jboss.wiki.WikiPage;
import org.jboss.wiki.WikiSession;

public class RecentChangesPlugin extends WikiInsidePlugin {

	@Override
	public String process(WikiPage wikiPage, WikiSession wikiSession,
			HashMap<String, String> attributes) {
		StringBuilder recentChanges = new StringBuilder();

		Integer numOfDays = Integer.MAX_VALUE;

		if (attributes.get("since") != null) {

			try {
				numOfDays = Integer.valueOf(attributes.get("since"));
			} catch (NumberFormatException e) {
				numOfDays = Integer.MAX_VALUE;
			}

		}

		if (numOfDays == Integer.MAX_VALUE) {
			recentChanges.append("!!Full recent changes\n");
		} else
			recentChanges.append("!!Recent changes from last ").append(
					numOfDays).append(" days\n");

		recentChanges.append("----\n");

		int offset = recentChanges.length();

		Set<String> pages = wikiEngine.getAllPageNames(wikiPage.getLangCode());

		TreeMap<String, TreeSet<String>> sortedByDate = new TreeMap<String, TreeSet<String>>();

		// get now date
		Calendar now = Calendar.getInstance();
		Calendar then = Calendar.getInstance();
		now.setTime(new Date());

		for (String name : pages) {
			WikiPage temp = wikiEngine.getByName(name, null, wikiPage.getLangCode());

			// log.debug("name: "+name+" "+temp.getName());
			then.setTime(temp.getEditDate());

			then.add(Calendar.DAY_OF_MONTH, numOfDays);

			if (then.after(now)) {
				// this page has been edited in last numOfDays days
				Calendar cal = Calendar.getInstance();
				String key;

				cal.setTime(temp.getEditDate());

				String month = String.valueOf(cal.get(Calendar.MONTH) + 1);
				String day = String.valueOf(cal.get(Calendar.DAY_OF_MONTH));

				if (month.length() == 1)
					month = "0" + month;

				if (day.length() == 1)
					day = "0" + day;

				// create key
				key = cal.get(Calendar.YEAR) + "/" + (month) + "/" + day;

				if (sortedByDate.get(key) == null) {
					TreeSet<String> set = new TreeSet<String>();
					set.add(temp.getName());
					sortedByDate.put(key, set);
				} else {
					sortedByDate.get(key).add(temp.getName());
				}
			}

		}

		// add pages to recentChanges page

		Set<String> keySet = sortedByDate.keySet();

		for (String date : keySet) {
			StringBuilder day = new StringBuilder();

			day.append("!''").append(date).append("''\n");
			for (String pageName : sortedByDate.get(date)) {
				day.append("[").append(pageName).append("]\\\\\n");
			}

			recentChanges.insert(offset, day.toString());
		}

		return recentChanges.toString();
	}

	@Override
	public void init() {
		// TODO Auto-generated method stub

	}

}
