/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki;

import java.io.File;
import java.io.InputStream;
import java.util.Set;

/**
 * @author <a href="mailto:tomasz.szymanski@jboss.com">Tomasz Szymanski</a>
 *
 */
public interface AttachmentDataSource {
	
	public static String attTrashName = "trash/attachments";
    
	/**Add atachment to a given page.
	 * 
	 * @param attFile File of the attachment.
	 * @param attName Name of the attachment.
	 * @param page Page to add atachment to.
	 * @param user Username of user adding the attachment.
	 */
	public void addAttachment(InputStream attFile, String attName, String uid, String user);
    
    /**Gets attachment list for a given page.
     * @param page Page to get list for.
     * @return Set of all attachment names.
     */
    public Set<String> getAttachmentsSet(String uid);
    
    /**Get appropriate attachment for a given page.
     * 
     * @param pageName Name of the page to get attachment from.
     * @param attachmentName Name of the attachment.
     * @return Desired attachment or null if it doesn't exists.
     */
    public WikiAttachment getAttachment(String pageName, String attachmentName);
    
    /**Get appropriate attachment for a given page at given version.
     * 
     * @param pageName Name of the page to get attachment from.
     * @param attachmentName Name of the attachment.
     * @param version Desired version of attachment.
     * @return Desired attachment or null if it doesn't exists.
     */
    public WikiAttachment getAttachment(String pageName, String attachmentName, int version);
    
    /**Gets last version of the given attachment.
     * 
     * @param pageName Name of the page to get attachment's version from.
     * @param attachmentName Name of the attachment.
     * @return attachment version
     */
    public int getLastAttachmentVersion(String pageName, String attachmentName);
    
    /**Gets size of attachment at given version.
     * 
     * @param pageName Name of the page to get attachment's size from.
     * @param attachmentName Name of the attachment.
     * @param version Version of the attachment to count size for.
     * @return attachment size
     */
    public long getAttachmentSize(String pageName, String attachmentName, int version);
    
    /** Deletes (or moves to trash) given attachment from a given page.
     * 
     * @param pageName Name of the page to delete attachment from.
     * @param attachmentName Attachment name.
     * @return true if attachemnt was deleted. False otherwise.
     */
    public boolean deleteAttachment(String pageName, String attachmentName);
    
    /** Deletes (or moves to trash) all attachments from a given page.
     * 
     * @param pageName Name of the page to delete attachments from.
     * @return true if attachemnts were deleted. False otherwise.
     */
    public boolean deleteAttachments(String pageName);
    
    /**Sets wikiEngine reference
	 * @param wikiEngine
	 */
	public void setWikiEngine(WikiEngine wikiEngine);

	/**Set language code for current dataSource.
	 * @param langCode code of the language
	 */
	public void setLanguageCode(String langCode);
	
	/**Adds langCode (to descriptor). This should be only called to default DataSource
	 * @param langCode Two-letter language code
	 * @param langDesc Language description
	 */
	public void addLangCode(String langCode, String langDesc);
}
