/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki;

import java.util.StringTokenizer;
import java.util.Vector;

public class WikiSearch {
	Vector<String> requestTokens;
	Vector<String> forbiddenTokens;
	Vector<String> requiredTokens;
	
	public WikiSearch(String searchQuery) {
		requestTokens = new Vector<String>();
		forbiddenTokens = new Vector<String>();
		requiredTokens = new Vector<String>();
		
        StringTokenizer st = new StringTokenizer( searchQuery, " \t," );


        //
        //  Parse incoming search string
        //

        while( st.hasMoreTokens() )
        {
            String token = st.nextToken().toLowerCase();


            switch( token.charAt(0) )
            {
              case '+':
                token = token.substring(1);
                requiredTokens.add(token);
                break;
                
              case '-':
            	token = token.substring(1);
                forbiddenTokens.add(token);
                break;

              default:
                requestTokens.add(token);
                break;
            }
        }
	}
	
	public int matches(String content) {
		int score = 0;
		
		for (int i = 0; i < forbiddenTokens.size(); i++) {
			if (content.indexOf(forbiddenTokens.get(i)) != -1) {
				// there is forbidden token - return 0
				return 0;
			}
		}
		
		for (int i = 0; i < requiredTokens.size(); i++) {
			if (content.indexOf(requiredTokens.get(i)) == -1) {
				// lack of one of the required tokens - return 0
				return 0;
			}
		}
		
		/*if (requiredTokens.size() > 0) {
			// there is at least one requirted token and it has been found
			return true;
		}*/
		
		for (int i = 0; i < requestTokens.size(); i++) {
			int fromIndex = -1;
			
			while ((fromIndex = content.indexOf(requestTokens.get(i), fromIndex+1)) != -1) {
				// found at least one required token
				score++;
			}
		}
		
		// return counted score
		return score;
	}
}
