/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki;

import java.util.Vector;

import org.jboss.logging.Logger;

/**
 * <p>
 * </p>
 * 
 */
/**
 * 
 * @author <a href="mailto:dsicore@jboss.org">Damon Sicore</a>
 * @author <a href="mailto:tomasz.szymanski@jboss.com">Tomasz Szymanski</a>
 * @version $Id$
 */
public class WikiType {

	protected String name;

	protected WikiEngine wikiEngine;

	/**
	 * <p>
	 * </p>
	 * 
	 */
	protected WikiContext wikiContext;

	protected Vector<WikiPlugin> plugins = new Vector<WikiPlugin>();
	
	protected Logger log = Logger.getLogger(this.getClass());

	public void addPlugin(String pluginName, String pluginClass) {

		WikiPlugin plugin = null;

		try {
			plugin = (WikiPlugin) Thread.currentThread().getContextClassLoader().loadClass(pluginClass).newInstance();
		} catch (Exception e) {
			log.error("Error while loading plugin: " + pluginName
					+ "\nclass: " + pluginClass + "\n" + e);
		}

		if (plugin != null) {
			plugin.setWikiType(this);
			
			plugins.add(plugin);

			plugin.setWikiEngine(wikiEngine);

			plugin.setName(pluginName);

			// run init() function
			plugin.init();

			log.info("Plugin added: "
					+ pluginName + " class: " + pluginClass);
		}

	}

	/**
	 * <p>
	 * Processes given WikiPage with the apropriate plugins, connected to this
	 * WikiType
	 * </p>
	 * 
	 * 
	 * @return processed WikiPage (copy - not exact reference)
	 * @param wikiPage
	 *            page to process
	 * @param wikiSession
	 *            current session
	 */
	public WikiPage process(WikiPage wikiPage, WikiSession wikiSession) {
		// process through all plugins

		WikiPage newPage = null;

		if (getReference()) {
			// pass reference
			newPage = wikiPage;
		} else {
			try {
				newPage = (WikiPage) wikiPage.clone();
			} catch (CloneNotSupportedException cnse) {
				log.error("cannot clone the page: " + cnse);
			}
		}

		// execute the plugins
		for (int i = 0; i < plugins.size(); i++) {
			// log.info("Executing plugin:
			// "+plugins.get(i).getName());
			newPage = (plugins.get(i)).process(newPage, wikiSession);
		}

		// clear session attributes passed in uri
		int i = 1;

		if (wikiSession != null)
			while (wikiSession.getAttribute("var" + i) != null) {
				wikiSession.removeAttribute("var" + i);
				i++;
			}

		// remove ALL temp variables for this session (as they are RELLLY temp)
		newPage.clearTempVariables(wikiSession);
		
		return newPage;
	}

	protected boolean getReference() {
		return false;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		log.info("Setting new WikiType name: " + name);
		this.name = name;
	}

	public void setWikiEngine(WikiEngine wikiEngine) {
		this.wikiEngine = wikiEngine;
	}

	public String getContentType() {
		return "text/html";
	}
}
