/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki.plugins;

import java.util.Date;

import org.jboss.wiki.WikiPage;

import org.jboss.wiki.WikiPlugin;
import org.jboss.wiki.WikiSession;

public class ATOMPlugin extends WikiPlugin {

	private DifferenceEngine differenceEngine;

	private void addItem(StringBuilder atomFeed, String title, String link,
			String description, Date modified, String hostURL) {
		atomFeed.append("<entry>\n");
		atomFeed.append("<title>").append(title).append("</title>\n");
		atomFeed.append("<link rel=\"alternate\" type=\"text/html\" href=\"")
				.append(link).append("\" />\n");
		atomFeed.append("<modified>").append(modified.toString()).append(
				"</modified>\n");
		atomFeed.append("<issued>").append(modified.toString()).append(
				"</issued>\n");
		atomFeed.append("<id>").append(title).append("</id>\n");
		atomFeed.append("<created>").append(modified.toString()).append(
				"</created>\n");
		atomFeed
				.append(
						"<content type=\"text/html\" mode=\"escaped\" xml:lang=\"en\" xml:base=\"")
				.append(hostURL).append("\" >");
		atomFeed.append(description).append("\n");
		atomFeed.append("</content>\n</entry>\n");
	}

	@Override
	public WikiPage process(WikiPage wikiPage, WikiSession wikiSession) {
		StringBuilder atomFeed = new StringBuilder(
				"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<?xml-stylesheet href=\"http://forge.jboss.com/blojsom/atom.css\" type=\"text/css\"?>\n<!-- name=\"generator\" content=\"JBoss Wiki ATOMPlugin\" -->\n");
		atomFeed
				.append("<feed version=\"0.3\" xmlns=\"http://purl.org/atom/ns#\" xml:lang=\"en\">\n");

		atomFeed.append("<title mode=\"escaped\">JBoss Forge Wiki: ").append(
				wikiPage.getName()).append("</title>\n");

		atomFeed.append("<link rel=\"alternate\" type=\"text/xml\" href=\"")
				.append((String) wikiSession.getAttribute("hostURL")).append(
						"/wiki/").append(
								wikiPage.getLangCode().equals(
										wikiEngine.defaultLangugeCode) ? "" : wikiPage
										.getLangCode().toLowerCase()
										+ "/").append("atom/").append(wikiPage.getName()).append(
						"\" />");

		atomFeed.append("<link href=\"").append(
				(String) wikiSession.getAttribute("hostURL")).append("/wiki/")
				.append(
						wikiPage.getLangCode().equals(
								wikiEngine.defaultLangugeCode) ? "" : wikiPage
								.getLangCode().toLowerCase()
								+ "/").append(wikiPage.getName()).append(
						"\" />\n");

		atomFeed.append("<tagline>").append(wikiPage.getName()).append(
				"</tagline>\n");
		atomFeed
				.append("<generator url=\"http://labs.jboss.com/products/jbosswiki\" version=\"JBoss Wiki beta\">JBoss Wiki</generator>\n");
		atomFeed
				.append("<copyright mode=\"escaped\">Copyright &#169; 2005 Tomasz Szymanski (tomasz-dot-szymanski-at-jboss-dot-com)</copyright>");

		/*
		 * atomFeed.append("<description>JBoss Wiki: " + wikiPage.getName() + "</description>\n");
		 * atomFeed.append("<language>en</language>\n");
		 */

		for (int i = wikiPage.getLastVersion(); i > 0; i--) {
			String content;

			if (i > 1) {
				content = differenceEngine
						.makeDiff(
								wikiPage.getPageAtVersion(true, i)
										.getPageContent(),
								wikiPage.getPageAtVersion(true, i - 1)
										.getPageContent()).replaceAll("&",
								"&amp;").replaceAll("<", "&lt;").replaceAll(
								">", "&gt;").replaceAll("\n", "<br />\n");
			} else {
				content = "This is first version of the page so it doesn't have diff yet";
			}

			addItem(atomFeed, wikiPage.getName() + " rev: " + i,
					(String) wikiSession.getAttribute("hostURL")
							+ getProperty("wikiHome").replaceAll("&", "&amp;")
							+ "&amp;page=" + wikiPage.getName()
							+ "&amp;version=" + i + "&amp;language=" + wikiPage.getLangCode(), content, wikiPage
							.getEditDate(), (String) wikiSession
							.getAttribute("hostURL"));
		}

		atomFeed.append("</feed>\n");

		wikiPage.setContent(atomFeed.toString());

		return wikiPage;
	}

	@Override
	public void init() {
		differenceEngine = new DifferenceEngine("UTF-8");
	}

}
