/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki.plugins;

import java.util.Calendar;
import java.util.Date;
import java.util.Set;
import java.util.TreeMap;
import java.util.TreeSet;

import org.jboss.wiki.WikiPage;
import org.jboss.wiki.WikiPlugin;
import org.jboss.wiki.WikiSession;

public class RecentlyChangedPagesPlugin extends WikiPlugin {

	private int numOfDays = 30; // just initialization if sth goes wrong. Real

	// number is taken from wikiPlugin.properties

	@Override
	public WikiPage process(WikiPage wikiPage, WikiSession wikiSession) {
		StringBuilder recentChanges = new StringBuilder();

		recentChanges.append("<h3>Recent changes from last ").append(numOfDays)
				.append(" days</h3>\n");
		recentChanges.append("<hr>\n");
		recentChanges.append(HTMLTranslatorParts.pagePartRegexStart);

		int offset = recentChanges.length();

		Set<String> pages = wikiEngine.getAllPageNames(wikiPage.getLangCode());
		
		TreeMap<String, TreeSet<String>> sortedByDate = new TreeMap<String, TreeSet<String>>();

		// get now date
		Calendar now = Calendar.getInstance();
		Calendar then = Calendar.getInstance();
		now.setTime(new Date());

		for (String name : pages) {
			WikiPage temp = wikiEngine.getByName(name, null, wikiPage.getLangCode());

			//log.debug("name: "+name+" "+temp.getName());
			then.setTime(temp.getEditDate());

			then.add(Calendar.DAY_OF_MONTH, numOfDays);

			if (then.after(now)) {
				// this page has been edited in last numOfDays days
				Calendar cal = Calendar.getInstance();
				String key;
				
				cal.setTime(temp.getEditDate());

				String month = String.valueOf(cal.get(Calendar.MONTH) + 1);
				String day = String.valueOf(cal.get(Calendar.DAY_OF_MONTH));

				if (month.length() == 1)
					month = "0" + month;

				if (day.length() == 1)
					day = "0" + day;

				// create key
				key = cal.get(Calendar.YEAR) + "/" + (month) + "/" + day;

				if (sortedByDate.get(key) == null) {
					TreeSet<String> set = new TreeSet<String>();
					set.add(temp.getName());
					sortedByDate.put(key, set);
				} else {
					sortedByDate.get(key).add(temp.getName());
				}
			}

		}

		// add pages to recentChanges page

		Set<String> keySet = sortedByDate.keySet();

		for (String date : keySet) {
			StringBuilder day = new StringBuilder();

			day.append("!''").append(date).append("''\n");
			for (String pageName : sortedByDate.get(date)) {
				day.append("[").append(pageName).append("]\\\\\n");
			}

			recentChanges.insert(offset, day.toString());
		}

		recentChanges.append(HTMLTranslatorParts.pagePartRegexEnd).append("\n");

		wikiPage.setContent(recentChanges.toString());

		return wikiPage;
	}

	@Override
	public void init() {
		if (getProperty("recentDays") != null) {
			numOfDays = Integer.valueOf(getProperty("recentDays"));
		}
	}

}
