package org.jboss.wiki.plugins;

import java.util.Set;
import java.util.TreeSet;

import org.jboss.logging.Logger;
import org.jboss.wiki.AdminSimpleCredentials;
import org.jboss.wiki.WikiContext;
import org.jboss.wiki.WikiInsidePlugin;
import org.jboss.wiki.WikiPage;
import org.jboss.wiki.WikiSession;

/**Abstract class for inside plugins that work on references.
 * @author tomek
 *
 */
public abstract class RefsManipulatingInsidePlugin extends WikiInsidePlugin {

	private static final String refsWikiType = "refs";
	
	private Logger log = Logger.getLogger(this.getClass());

	protected String getLink(String pageName, Integer maxwidth) {
		if ((maxwidth != null) && (pageName.length() > maxwidth)) {
			return "[" + pageName.substring(0, maxwidth - 3) + "...|"
					+ pageName + "]\\\\";
		} else {
			return "[" + pageName + "]\\\\";
		}
	}

	protected Set<String> getAllRefs(WikiSession wikiSession, String langCode) {

		Set<String> pageNames = wikiEngine.getAllPageNames(langCode);

		Set<String> allRefs = new TreeSet<String>();

		WikiContext wikiContext = new WikiContext(new AdminSimpleCredentials(), wikiEngine
				.getWikiType(refsWikiType), wikiSession);

		for (String pageName : pageNames) {

			WikiPage page = wikiEngine.getByName(pageName, wikiContext, langCode);

			Set<String> refs = (Set<String>) page.getPermVariable("refs");

			if (refs != null)
				allRefs.addAll(refs);
		}

		return allRefs;
	}

	protected Set<String> getRefsFor(String uid, Integer max,
			WikiSession wikiSession, String langCode) {

		Set<String> refsFor = new TreeSet<String>();

		Set<String> pageNames = wikiEngine.getAllPageNames(langCode);

		WikiContext wikiContext = new WikiContext(new AdminSimpleCredentials(), wikiEngine
				.getWikiType(refsWikiType), wikiSession);

		for (String pageName : pageNames) {

			WikiPage page = wikiEngine.getByName(pageName, wikiContext, langCode);

			Set<String> refs = (Set<String>) page.getPermVariable("refs");

			if (refs != null && refs.contains(uid)) 
				refsFor.add(page.getName());

		}

		return refsFor;
	}

}
