/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki.plugins;

import org.jboss.wiki.Credentials;
import org.jboss.wiki.WikiPage;
import org.jboss.wiki.WikiPlugin;
import org.jboss.wiki.WikiSession;

/**
 * Plugin that adds user to watch list (for sending on-change notifications)
 * 
 * @author <a href="mailto:tomasz.szymanski@jboss.com">Tomasz Szymanski</a>
 * 
 */
public class WatchListPlugin extends WikiPlugin {

	public static final String WATCH_PROPERTY = "notifications";

	@Override
	public WikiPage process(WikiPage wikiPage, WikiSession wikiSession) {
		Credentials cred = (Credentials) wikiSession
				.getAttribute(WikiSession.CREDENTIALS);

		if (cred.isLoggedIn()) {
			String notifications = wikiPage
					.getMetaDataProperty(WatchListPlugin.WATCH_PROPERTY);

			if (notifications == null) {
				notifications = "";
			} else if (notifications.startsWith(";")) {
				notifications = notifications.substring(1);
			}

			String[] users = notifications.split(";");

			String notificationsGlobal = wikiEngine.getGlobalProperty(
					WATCH_PROPERTY, wikiPage.getLangCode());

			if (notificationsGlobal == null) {
				notificationsGlobal = "";
			} else if (notificationsGlobal.startsWith(";")) {
				notificationsGlobal = notificationsGlobal.substring(1);
			}

			String[] usersGlobal = notificationsGlobal.split(";");

			if (wikiSession.getAttribute("var1") != null
					&& wikiSession.getAttribute("var1").equals("watch")
					&& wikiSession.getAttribute("var2") != null
					&& wikiSession.getAttribute("var2").equals("toggle")) {
				// toggle page watch/unwatch

				log.debug("Adding user: " + cred.getName()
						+ " to watchlist for page: " + wikiPage.getName());

				notifications = toggleWatch(users, cred.getName(), cred
						.getEmail());
				users = notifications.split(";");

				wikiPage.setMetaDataProperty(WATCH_PROPERTY, notifications);

			} else if (wikiSession.getAttribute("var1") != null
					&& wikiSession.getAttribute("var1").equals("watchGlobal")
					&& wikiSession.getAttribute("var2") != null
					&& wikiSession.getAttribute("var2").equals("toggle")) {
				// toggle global page watch/unwatch

				log.debug("Adding user: " + cred.getName()
						+ " to watchlist for page: " + wikiPage.getName());

				notificationsGlobal = toggleWatch(usersGlobal, cred.getName(),
						cred.getEmail());
				usersGlobal = notificationsGlobal.split(";");

				wikiEngine.setGlobalProperty(WATCH_PROPERTY,
						notificationsGlobal, wikiPage.getLangCode());

			}

			StringBuffer buffer = new StringBuffer(wikiPage.getContent());
			buffer.append("<hr />\n").append("<h3>Page watching</h3>\n");

			boolean watcher = userInWatchList(users, cred.getName());

			buffer.append(
					(watcher) ? "You are watching this page. "
							: "You are not watching this page. ").append(
					"<a href=\"").append(
					wikiSession.getAttribute(WikiSession.ACTION_URL)).append(
					"&page=").append(wikiPage.getName()).append(
					"&var1=watch&var2=toggle\" >[").append(
					(watcher) ? "Stop watching this page" : "Watch this page")
					.append("]</a><br />");

			watcher = userInWatchList(usersGlobal, cred.getName());

			buffer.append(
					(watcher) ? "Your global watch is switched ON. "
							: "Your global watch is switched OFF. ").append(
					"<a href=\"").append(
					wikiSession.getAttribute(WikiSession.ACTION_URL)).append(
					"&page=").append(wikiPage.getName()).append(
					"&var1=watchGlobal&var2=toggle\" >[").append(
					(watcher) ? "Switch it off" : "Switch it on").append(
					"]</a>");

			wikiPage.setContent(buffer.toString());
		}

		return wikiPage;
	}

	private String toggleWatch(String[] users, String user, String email) {
		String notifs = "";
		if (users.length > 0 && userInWatchList(users, user)) {
			for (int i = 0; i < users.length; i += 2) {
				if (!users[i].equals(user)) {
					notifs += users[i] + ";" + users[i + 1] + ";";
				}
			}
		} else {
			for (int i = 0; i < users.length; i++) {
				if (notifs.length() != 0
						|| (users[i].length() != 0 && notifs.length() == 0)) {
					notifs += users[i] + ";";
				}
			}
			notifs += user + ";" + email + ";";
		}

		return notifs;
	}

	@Override
	public void init() {

	}

	private boolean userInWatchList(String[] allUsers, String user) {
		boolean is = false;

		for (int i = 0; i < allUsers.length && is == false; i += 2) {
			if (allUsers[i].equals(user)) {
				is = true;
			}
		}

		return is;
	}
}
