package org.jboss.wiki;

import java.util.Date;

import javax.ejb.Stateless;
import javax.mail.Address;
import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.Message.RecipientType;
import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;

import org.jboss.logging.Logger;
import org.jboss.wiki.management.EMailNotifier;
import org.jboss.wiki.management.NotificationMsg;

@Stateless
public class EMailNotifierSLSB implements EMailNotifier {

	private static final Logger log = Logger.getLogger(EMailNotifier.class);

	public synchronized void sendNotification(NotificationMsg notifications) {

		try {
			Session session = (Session) PortableRemoteObject.narrow(
					new InitialContext().lookup("java:Mail"), Session.class);

			log.debug("Got email notification msg");

			for (String email : notifications.getEmails()) {
				log.debug("MDB for: " + email);

				StringBuffer buffer = null;
				Address[] to = null;
				MimeMessage m = new MimeMessage(session);

				if (email != null) {
					m
							.setFrom(new InternetAddress(notifications
									.getFromEmail()));
					to = new InternetAddress[] { new InternetAddress(email) };
					m.setRecipients(RecipientType.TO, to);
					m.setSubject("[JBossWiki] Page change notification: "
							+ notifications.getPageName());

					m.setSentDate(new Date());
					buffer = new StringBuffer();

					buffer
							.append(
									"This message is generated automatically. Please do not reply. To remove yourself from the watch list please go to ")
							.append(notifications.getPageLink()).append(
									"<br />\n");
					buffer.append(notifications.getPageContent());

					m.setContent(buffer.toString(),
							"text/html; charset=\"UTF-8\"");
					Transport.send(m);
					log.debug("Notification send to: "+email);
				}
			}
		} catch (ClassCastException e) {
			log.error(e);
		} catch (NamingException e) {
			log.error(e);
		} catch (AddressException e) {
			log.error(e);
		} catch (MessagingException e) {
			log.error(e);
		}
	}

}
