/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki.test;

import java.util.Map;

import org.jboss.wiki.exceptions.WikiException;

public class FindPagesTest extends WikiTest {

	private final static String CONTENT_MOD = "1234567890";
	
	public void testFinding() throws WikiException {
		String page1 = createTestPage(plainUser, PAGE_CONTENT);
		
		String page2 = createTestPage(plainUser, PAGE_CONTENT + CONTENT_MOD);
		
		String page3 = createTestPage(plainUser, CONTENT_MOD + PAGE_CONTENT + CONTENT_MOD);
		
		// first search - just page content - all pages should be returned
		Map<String, Integer> searchResult = wikiEngine.findPages(PAGE_CONTENT, langCode);
		
		// look if pages are in results
		assertTrue(searchResult.keySet().contains(page1));
		assertTrue(searchResult.keySet().contains(page2));
		assertTrue(searchResult.keySet().contains(page3));
		
		// only content
		Map<String, Integer> searchResult2 = wikiEngine.findPages(CONTENT_MOD, langCode);
		
		// first page shouldn't be in results
		assertFalse(searchResult2.keySet().contains(page1));
		
		// 2 and 3 pages should be available
		assertTrue(searchResult2.keySet().contains(page2));
		assertTrue(searchResult2.keySet().contains(page3));
		
		// page 3 should have bigger result
		
		assertTrue(searchResult2.get(page3).compareTo(searchResult2.get(page2)) > 0);
		
		// page2 name
		Map<String, Integer> searchResult3 = wikiEngine.findPages(page2, langCode);
		
		//this should return only page2
		assertFalse(searchResult3.keySet().contains(page1));
		assertTrue(searchResult3.keySet().contains(page2));
		assertFalse(searchResult3.keySet().contains(page3));
	}

}
