/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki.test;

import org.jboss.wiki.WikiPage;
import org.jboss.wiki.exceptions.WikiException;

public class PropsTest extends WikiTest {

	private final static String PROP1 = "property1";

	private final static String KEY1 = "bim bom";

	private final static String PROP2 = "pRoperty2";

	private final static String KEY2 = "bele bele BYM";

	private final static String PROP3 = "WielkaPropa";

	private final static String KEY3 = "I don't like Yor";

	public void testProperties() throws WikiException {
		String testPage = createTestPage(plainUser, PAGE_CONTENT);

		WikiPage page = wikiEngine.getByName(testPage, null, langCode);

		// set some properties
		page.setMetaDataProperty(PROP1, KEY1);
		page.setMetaDataProperty(PROP2, KEY2);
		page.setMetaDataProperty(PROP3, KEY3);
		
		// refresh page
		wikiEngine.refreshPage(testPage, langCode);
		
		// reload page
		page = wikiEngine.getByName(testPage, null, langCode);
		
		// check properties
		assertEquals(page.getMetaDataProperty(PROP1), KEY1);
		assertEquals(page.getMetaDataProperty(PROP2), KEY2);
		assertEquals(page.getMetaDataProperty(PROP3), KEY3);
		
		// remove property
		page.removeMetaDataProperty(PROP2);
		
		// refresh page
		wikiEngine.refreshPage(testPage, langCode);
		
		// reload page
		page = wikiEngine.getByName(testPage, null, langCode);
		
		// it should be null now
		assertNull(page.getMetaDataProperty(PROP2));
	}
}
