/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki.test;

import java.util.Date;
import java.util.Set;
import java.util.TreeSet;

import org.jboss.wiki.WikiPage;
import org.jboss.wiki.exceptions.WikiException;

public class SubPagesTest extends WikiTest {

	private static final String SUB_PAGE_1 = "SubPage1";

	private static final String SUB_PAGE_2 = "SubPage2";

	private static final String PAGE_CONTENT_2 = "Sub page content 1";

	private static final String PAGE_CONTENT_3 = "Sub page content 2";
	
	private static final String SUB_PAGE_PREFIX = "TestPageSubpages";

	public void testSubpagesList() throws WikiException {
		String page = createTestPage(plainUser, PAGE_CONTENT);
		
		// create first subpage
		WikiPage subPage1 = new WikiPage(page + "/" + SUB_PAGE_1, plainUser,
				PAGE_CONTENT_2, 1, 1, new Date(), wikiEngine, true, true, null,
				null, PAGE_CONTENT_2.length(), langCode);
		
		wikiEngine.savePage(plainUser, subPage1, langCode, testWikiSession);
		
		//add to "to-delete" list
		pagesToDelete.add(page+"/"+SUB_PAGE_1);
		
		// create second subpage
		WikiPage subPage2 = new WikiPage(page + "/" + SUB_PAGE_2, plainUser,
				PAGE_CONTENT_3, 1, 1, new Date(), wikiEngine, true, true, null,
				null, PAGE_CONTENT_3.length(), langCode);
		
		wikiEngine.savePage(plainUser, subPage2, langCode, testWikiSession);
		
		//add to "to-delete" list
		pagesToDelete.add(page+"/"+SUB_PAGE_2);
		
		Set<String> subPagesList = wikiEngine.getPagesFor(page, langCode);
		
		// construct new set with new subpages' names
		Set<String> mySet = new TreeSet<String>();
		mySet.add(page+"/"+SUB_PAGE_1); mySet.add(page+"/"+SUB_PAGE_2);
		
		// check if both sets are the same
		assertEquals(subPagesList, mySet);
	}
	
	public void testSubpagesDelete() throws WikiException {
		Set<String> createdPages = new TreeSet<String>();
		
		String page = getUniqueName(SUB_PAGE_PREFIX);
		
		// create first page
		WikiPage rootPage = new WikiPage(page, plainUser,
				PAGE_CONTENT_2, 1, 1, new Date(), wikiEngine, true, true, null,
				null, PAGE_CONTENT_2.length(), langCode);
		
		wikiEngine.savePage(plainUser, rootPage, langCode, testWikiSession);
		createdPages.add(page);
		
		// create first subpage
		WikiPage subPage1 = new WikiPage(page + "/" + SUB_PAGE_1, plainUser,
				PAGE_CONTENT_2, 1, 1, new Date(), wikiEngine, true, true, null,
				null, PAGE_CONTENT_2.length(), langCode);
		
		wikiEngine.savePage(plainUser, subPage1, langCode, testWikiSession);
		createdPages.add(page + "/" + SUB_PAGE_1);
		
		// create second subpage
		WikiPage subPage2 = new WikiPage(page + "/" + SUB_PAGE_2, plainUser,
				PAGE_CONTENT_2, 1, 1, new Date(), wikiEngine, true, true, null,
				null, PAGE_CONTENT_2.length(), langCode);
		
		wikiEngine.savePage(plainUser, subPage2, langCode, testWikiSession);
		createdPages.add(page + "/" + SUB_PAGE_2);
		
		// create first subsubpage
		WikiPage subSubPage1 = new WikiPage(page + "/" + SUB_PAGE_1 + "/" + SUB_PAGE_1, plainUser,
				PAGE_CONTENT_2, 1, 1, new Date(), wikiEngine, true, true, null,
				null, PAGE_CONTENT_2.length(), langCode);
		
		wikiEngine.savePage(plainUser, subSubPage1, langCode, testWikiSession);
		createdPages.add(page + "/" + SUB_PAGE_1 + "/" + SUB_PAGE_1);
		
		// add a page that is more deep inside
		String name = page + "/" + SUB_PAGE_1 + "/" + SUB_PAGE_1 + "/" + SUB_PAGE_2 + "/" + SUB_PAGE_2 + "/" + SUB_PAGE_1;
		WikiPage subSubmultiple = new WikiPage(name, plainUser,
				PAGE_CONTENT_2, 1, 1, new Date(), wikiEngine, true, true, null,
				null, PAGE_CONTENT_2.length(), langCode);
		
		wikiEngine.savePage(plainUser, subSubmultiple, langCode, testWikiSession);
		createdPages.add(name);
		
		
		// all pages should be there
		for (String s : createdPages) {
			assertTrue(wikiEngine.pageExists(s, langCode));
		}
		
		wikiEngine.deletePage(page, true, langCode);
		
		// after deleting - no pages :)
		for (String s : createdPages) {
			assertFalse(wikiEngine.pageExists(s, langCode));
		}
		
	}
}

