/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki.test;

import java.util.Set;

import org.jboss.wiki.Credentials;

public class TestCredentials extends Credentials {
	private boolean logedIn = false;
	private boolean admin = false;
	private Set<String> roles;
	
	public TestCredentials(boolean logedIn, boolean admin) {
		init(logedIn, admin);
	}
	
	public TestCredentials(boolean logedIn, boolean admin, Set<String> roles) {
		init(logedIn, admin);
		this.roles = roles;
	}
	
	private void init(boolean logedIn, boolean admin) {
		this.admin = admin;
		this.logedIn = logedIn;
	}
	
	@Override
	public String getName() {
		return (isLoggedIn()) ? ((isAdmin()) ? "admin" : "test-user") : "Unknown";
	}

	@Override
	public boolean isLoggedIn() {
		return logedIn;
	}

	@Override
	public boolean isAdmin() {
		return admin;
	}

	@Override
	public void setParam(Object param) {
		// Do nothing
		
	}

	@Override
	public boolean isUserInRole(String role) {
		if (roles == null) {
			return false;
		}
		
		return (roles.contains(role));
	}

	@Override
	public Set<String> getAllRoles() {
		return roles;
	}

	@Override
	public String getEmail() {
		return null;
	}
	
}